## yam
Yet another monitoring tool using correlations of ambient noise

[![build status](https://travis-ci.org/trichter/yam.svg?branch=master)](https://travis-ci.org/trichter/yam)
[![codecov](https://codecov.io/gh/trichter/yam/branch/master/graph/badge.svg)](https://codecov.io/gh/trichter/yam)
[![pypi version](https://img.shields.io/pypi/v/yam.svg)](https://pypi.python.org/pypi/yam)
[![python version](https://img.shields.io/pypi/pyversions/yam.svg)](https://python.org)


#### Resources

* [Documentation](http://yam.readthedocs.io)
* Showcase / advanced tutorial -> [notebook](http://nbviewer.jupyter.org/github/trichter/notebooks/blob/master/yam_velocity_variations_patcx/processing_patcx.ipynb)
* Get help at the [seistools](https://lserv.uni-jena.de/mailman/listinfo/seistools) mailing list